@@ -2,6 +2,7 @@ import base64
 import ipaddress
 
 from typing import Any
+from typing import Optional
 from typing import Type
 from typing import Union
 
@@ -107,10 +108,13 @@ class BaseplateSession:
 
     """
 
-    def __init__(self, adapter: HTTPAdapter, name: str, span: Span) -> None:
+    def __init__(
+        self, adapter: HTTPAdapter, name: str, span: Span, client_name: Optional[str] = None
+    ) -> None:
         self.adapter = adapter
         self.name = name
         self.span = span
+        self.client_name = client_name
 
     def delete(self, url: str, **kwargs: Any) -> Response:
         """Send a DELETE request.
@@ -200,10 +204,13 @@ class BaseplateSession:
 
     def send(self, request: PreparedRequest, **kwargs: Any) -> Response:
         """Send a :py:class:`~requests.PreparedRequest`."""
-        with self.span.make_child(f"{self.name}.request") as span:
-            span.set_tag("http.method", request.method)
-            span.set_tag("http.url", request.url)
-
+        tags = {
+            "protocol": "http",
+            "http.method": request.method,
+            "http.url": request.url,
+            "http.slug": self.client_name if self.client_name is not None else self.name,
+        }
+        with self.span.make_child(f"{self.name}.request").with_tags(tags) as span:
             self._add_span_context(span, request)
 
             # we cannot re-use the same session every time because sessions re-use the same
@@ -216,7 +223,8 @@ class BaseplateSession:
             session.mount("https://", self.adapter)
             response = session.send(request, **kwargs)
 
-            span.set_tag("http.status_code", response.status_code)
+            http_status_code = response.status_code
+            span.set_tag("http.status_code", http_status_code)
         return response
 
 
@@ -257,15 +265,23 @@ class RequestsContextFactory(ContextFactory):
         :py:func:`http_adapter_from_config`.
     :param session_cls: The type for the actual session object to put on the
         request context.
+    :param client_name: Custom name to be emitted under the http_slug label
+        for prometheus metrics. Defaults back to session_cls.name if None
 
     """
 
-    def __init__(self, adapter: HTTPAdapter, session_cls: Type[BaseplateSession]) -> None:
+    def __init__(
+        self,
+        adapter: HTTPAdapter,
+        session_cls: Type[BaseplateSession],
+        client_name: Optional[str] = None,
+    ) -> None:
         self.adapter = adapter
         self.session_cls = session_cls
+        self.client_name = client_name
 
     def make_object_for_context(self, name: str, span: Span) -> BaseplateSession:
-        return self.session_cls(self.adapter, name, span)
+        return self.session_cls(self.adapter, name, span, client_name=self.client_name)
 
 
 class InternalRequestsClient(config.Parser):
@@ -288,9 +304,13 @@ class InternalRequestsClient(config.Parser):
 
     See :py:func:`http_adapter_from_config` for available configuration settings.
 
+    :param client_name: Custom name to be emitted under the http_slug label
+        for prometheus metrics. Defaults back to session_cls.name if None
+
     """
 
-    def __init__(self, **kwargs: Any) -> None:
+    def __init__(self, client_name: Optional[str] = None, **kwargs: Any) -> None:
+        self.client_name = client_name
         self.kwargs = kwargs
 
         if "validator" in kwargs:
@@ -317,7 +337,9 @@ class InternalRequestsClient(config.Parser):
         adapter = http_adapter_from_config(
             raw_config, prefix=f"{key_path}.", validator=validator, **self.kwargs
         )
-        return RequestsContextFactory(adapter, session_cls=InternalBaseplateSession)
+        return RequestsContextFactory(
+            adapter, session_cls=InternalBaseplateSession, client_name=self.client_name
+        )
 
 
 class ExternalRequestsClient(config.Parser):
@@ -332,11 +354,17 @@ class ExternalRequestsClient(config.Parser):
 
     See :py:func:`http_adapter_from_config` for available configuration settings.
 
+    :param client_name: Custom name to be emitted under the http_slug label
+        for prometheus metrics. Defaults back to session_cls.name if None
+
     """
 
-    def __init__(self, **kwargs: Any) -> None:
+    def __init__(self, client_name: Optional[str] = None, **kwargs: Any) -> None:
+        self.client_name = client_name
         self.kwargs = kwargs
 
     def parse(self, key_path: str, raw_config: config.RawConfig) -> RequestsContextFactory:
         adapter = http_adapter_from_config(raw_config, f"{key_path}.", **self.kwargs)
-        return RequestsContextFactory(adapter, session_cls=BaseplateSession)
+        return RequestsContextFactory(
+            adapter, session_cls=BaseplateSession, client_name=self.client_name
+        )
