@@ -8,6 +8,7 @@ from typing import Callable
 from typing import Iterator
 from typing import Optional
 
+from prometheus_client import Gauge
 from thrift.protocol.TProtocol import TProtocolException
 from thrift.Thrift import TApplicationException
 from thrift.Thrift import TException
@@ -70,6 +71,21 @@ class ThriftContextFactory(ContextFactory):
 
     """
 
+    PROM_PREFIX = "bp_thrift_pool"
+    PROM_LABELS = ["client_cls"]
+
+    max_connections_gauge = Gauge(
+        f"{PROM_PREFIX}_max_size",
+        "Maximum number of connections in this thrift pool before blocking",
+        PROM_LABELS,
+    )
+
+    active_connections_gauge = Gauge(
+        f"{PROM_PREFIX}_active_connections",
+        "Number of connections currently in use in this thrift pool",
+        PROM_LABELS,
+    )
+
     def __init__(self, pool: ThriftConnectionPool, client_cls: Any):
         self.pool = pool
         self.client_cls = client_cls
@@ -83,6 +99,10 @@ class ThriftContextFactory(ContextFactory):
             },
         )
 
+        pool_name = type(self.client_cls).__name__
+        self.max_connections_gauge.labels(pool_name).set_function(lambda: self.pool.size)
+        self.active_connections_gauge.labels(pool_name).set_function(lambda: self.pool.checkedout)
+
     def report_runtime_metrics(self, batch: metrics.Client) -> None:
         batch.gauge("pool.size").replace(self.pool.size)
         batch.gauge("pool.in_use").replace(self.pool.checkedout)
@@ -148,11 +168,16 @@ def _build_thrift_proxy_method(name: str) -> Callable[..., Any]:
         last_error = None
 
         for time_remaining in self.retry_policy:
-            span = self.server_span.make_child(trace_name)
-            span.start()
-
             try:
                 with self.pool.connection() as prot:
+                    span = self.server_span.make_child(trace_name)
+                    span.set_tag("slug", self.namespace)
+
+                    client = self.client_cls(prot)
+                    method = getattr(client, name)
+                    span.set_tag("method", method.__name__)
+                    span.start()
+
                     baseplate = span.baseplate
                     if baseplate:
                         service_name = baseplate.service_name
@@ -187,8 +212,6 @@ def _build_thrift_proxy_method(name: str) -> Callable[..., Any]:
                     if edge_context:
                         prot.trans.set_header(b"Edge-Request", edge_context)
 
-                    client = self.client_cls(prot)
-                    method = getattr(client, name)
                     result = method(*args, **kwargs)
             except TTransportException as exc:
                 # the connection failed for some reason, retry if able
